# API de Series de Tiempo de la República Argentina

La API de Series de Tiempo de Argentina, permite consultar indicadores con evolución cronológica publicados en formatos abiertos por organismos de la Administración Pública Nacional.

Una [serie de tiempo](https://es.wikipedia.org/wiki/Serie_temporal) es una secuencia de observaciones o valores, medidos en determinados momentos del tiempo y ordenados cronológicamente.

<table>
    <tr><td>indice_tiempo</td><td>ipc_2016_nivel_general</td></tr>
    <tr><td>2017-04</td><td>0.28</td></tr>
    <tr><td>2017-05</td><td>0.24</td></tr>
    <tr><td>2017-06</td><td>0.22</td></tr>
    <tr><td>2017-07</td><td>0.22</td></tr>
    <tr><td>2017-08</td><td>0.23</td></tr>
    <tr><td>2017-09</td><td>0.24</td></tr>
    <tr><td>2017-10</td><td>0.23</td></tr>
    <tr><td>2017-11</td><td>0.22</td></tr>
    <tr><td>2017-12</td><td>0.25</td></tr>
    <tr><td>2018-01</td><td>0.25</td></tr>
    <tr><td>2018-02</td><td>0.26</td></tr>
    <tr><td>2018-03</td><td>0.26</td></tr>
</table>

Un [servicio web](https://es.wikipedia.org/wiki/Servicio_web), es una tecnología que permite intercambiar datos entre aplicaciones.

[`apis.datos.gob.ar/series/api/series/?ids=101.1_I2NG_2016_M_22:percent_change_a_year_ago&format=csv`](http://apis.datos.gob.ar/series/api/series/?ids=101.1_I2NG_2016_M_22:percent_change_a_year_ago&format=csv)

Estos indicadores son ejemplos de series de tiempo:

* [Inflación](http://apis.datos.gob.ar/series/api/series/?ids=101.1_I2NG_2016_M_22:percent_change_a_year_ago&format=csv)
* [Tipo de cambio](http://apis.datos.gob.ar/series/api/series/?ids=168.1_T_CAMBIOR_D_0_0_26&start_date=2018-07&limit=1000)
* [Nivel de actividad](http://apis.datos.gob.ar/series/api/series/?ids=143.3_NO_PR_2004_A_21&limit=1000)
